import re
import six
import warnings
from .address import address
from .numbers import PaymentID

class Payment(object):
    """
    A payment base class, representing payment not associated with any
    :class:`Account <monero.account.Account>`.

    This class is not intended to be turned into objects by the user,
    it is used by backends.
    """
    payment_id = None
    amount = None
    timestamp = None
    transaction = None
    local_address = None
    note = ''

    _reprstr = "{} @ {} {:.12f} id={}"

    def __init__(self, **kwargs):
        self.amount = kwargs.pop('amount', self.amount)
        self.timestamp = kwargs.pop('timestamp', self.timestamp)
        self.payment_id = kwargs.pop('payment_id', self.payment_id)
        self.transaction = kwargs.pop('transaction', self.transaction)
        self.local_address = kwargs.pop('local_address', self.local_address)
        self.note = kwargs.pop('note', self.note)
        if len(kwargs):
            raise ValueError("Excessive arguments for {}: {}".format(type(self), kwargs))

    def __repr__(self):
        return self._reprstr.format(
            self.transaction.hash, self.transaction.height or 'pool', self.amount, self.payment_id)


class IncomingPayment(Payment):
    """
    An incoming payment (one that increases the balance of an
    :class:`Account <monero.account.Account>`)
    """
    _reprstr = "in: {} @ {} {:.12f} id={}"


class OutgoingPayment(Payment):
    """
    An outgoing payment (one that decreases the balance of an
    :class:`Account <monero.account.Account>`)
    """
    destinations = None

    def __init__(self, **kwargs):
        self.destinations = kwargs.pop('destinations', [])
        super(OutgoingPayment, self).__init__(**kwargs)

    _reprstr = "out: {} @ {} {:.12f} id={}"


class Transaction(object):
    """
    A Monero transaction. Identified by `hash`, it can be a part of a block of some `height`
    or not yet mined (`height` is `None` then).

    This class is not intended to be turned into objects by the user,
    it is used by backends.
    """
    hash = None
    fee = None
    height = None
    timestamp = None
    key = None
    blob = None
    json = None
    confirmations = None

    @property
    def size(self):
        return len(self.blob)

    def __init__(self, **kwargs):
        self.hash = kwargs.get('hash', self.hash)
        self.fee = kwargs.get('fee', self.fee)
        self.height = kwargs.get('height', self.height)
        self.timestamp = kwargs.get('timestamp', self.timestamp)
        self.key = kwargs.get('key', self.key)
        self.blob = kwargs.get('blob', self.blob)
        self.json = kwargs.get('json', self.json)
        self.confirmations = kwargs.get('confirmations', self.confirmations)

    def __repr__(self):
        return self.hash


class PaymentManager(object):
    """
    A payment query manager, handling either incoming or outgoing payments of
    an :class:`Account <monero.account.Account>`.

    This class is not intended to be turned into objects by the user,
    it is used by backends.
    """
    account_idx = 0
    backend = None

    def __init__(self, account_idx, backend, direction):
        self.account_idx = account_idx
        self.backend = backend
        self.direction = direction

    def __call__(self, **filterparams):
        fetch = self.backend.transfers_in if self.direction == 'in' else self.backend.transfers_out
        return fetch(self.account_idx, PaymentFilter(**filterparams))


def _validate_tx_id(txid):
    if not bool(re.compile('^[0-9a-f]{64}$').match(txid)):
        raise ValueError("Transaction ID must be a 64-character hexadecimal string, not "
            "'{}'".format(txid))
    return txid


class _ByHeight(object):
    """A helper class used as key in sorting of payments by height.
    Mempool goes on top, blockchain payments are ordered with descending block numbers.

    **WARNING:** Integer sorting is reversed here.
    """
    def __init__(self, pmt):
        self.pmt = pmt
    def _cmp(self, other):
        sh = self.pmt.transaction.height
        oh = other.pmt.transaction.height
        if sh is oh is None:
            return 0
        if sh is None:
            return 1
        if oh is None:
            return -1
        return (sh > oh) - (sh < oh)
    def __lt__(self, other):
        return self._cmp(other) > 0
    def __le__(self, other):
        return self._cmp(other) >= 0
    def __eq__(self, other):
        return self._cmp(other) == 0
    def __ge__(self, other):
        return self._cmp(other) <= 0
    def __gt__(self, other):
        return self._cmp(other) < 0
    def __ne__(self, other):
        return self._cmp(other) != 0


class PaymentFilter(object):
    """
    A helper class that filters payments retrieved by the backend.

    This class is not intended to be turned into objects by the user,
    it is used by backends.
    """
    def __init__(self, **filterparams):
        self.min_height = filterparams.pop('min_height', None)
        self.max_height = filterparams.pop('max_height', None)
        self.unconfirmed = filterparams.pop('unconfirmed', False)
        self.confirmed = filterparams.pop('confirmed', True)
        _local_address = filterparams.pop('local_address', None)
        _tx_id = filterparams.pop('tx_id', None)
        _payment_id = filterparams.pop('payment_id', None)
        if len(filterparams) > 0:
            raise ValueError("Excessive arguments for payment query: {}".format(filterparams))
        if self.unconfirmed and (self.min_height is not None or self.max_height is not None):
            warnings.warn("Height filtering (min_height/max_height) has been requested while "
                    "also asking for unconfirmed transactions. These are mutually exclusive. "
                    "As mempool transactions have no height at all, they will be excluded "
                    "from the result.",
                    RuntimeWarning)
        if _local_address is None:
            self.local_addresses = []
        else:
            if isinstance(_local_address, six.string_types) \
                or isinstance(_local_address, six.text_type):
                local_addresses = [_local_address]
            else:
                try:
                    iter(_local_address)
                    local_addresses = _local_address
                except TypeError:
                    local_addresses = [_local_address]
            self.local_addresses = list(map(address, local_addresses))
        if _tx_id is None:
            self.tx_ids = []
        else:
            if isinstance(_tx_id, six.string_types) or isinstance(_tx_id, six.text_type):
                tx_ids = [_tx_id]
            else:
                try:
                    iter(_tx_id)
                    tx_ids = _tx_id
                except TypeError:
                    tx_ids = [_tx_id]
            self.tx_ids = list(map(_validate_tx_id, tx_ids))
        if _payment_id is None:
            self.payment_ids = []
        else:
            if isinstance(_payment_id, six.string_types) or isinstance(_payment_id, six.text_type):
                payment_ids = [_payment_id]
            else:
                try:
                    iter(_payment_id)
                    payment_ids = _payment_id
                except TypeError:
                    payment_ids = [_payment_id]
            self.payment_ids = list(map(PaymentID, payment_ids))

    def check(self, payment):
        ht = payment.transaction.height
        if ht is None:
            if not self.unconfirmed:
                return False
            if self.min_height is not None or self.max_height is not None:
                # mempool txns are filtered out if any height range check is present
                return False
        else:
            if not self.confirmed:
                return False
            if self.min_height is not None and ht < self.min_height:
                return False
            if self.max_height is not None and ht > self.max_height:
                return False
        if self.payment_ids and payment.payment_id not in self.payment_ids:
            return False
        if self.tx_ids and payment.transaction.hash not in self.tx_ids:
            return False
        if self.local_addresses and payment.local_address not in self.local_addresses:
            return False
        return True

    def filter(self, payments):
        return sorted(
            filter(self.check, payments),
            key=_ByHeight)



NET_MAIN = "main"
NET_STAGE = "stage"
NET_TEST = "test"

NETS = (NET_MAIN, NET_TEST, NET_STAGE)
MASTERADDR_NETBYTES = (18, 53, 24)
SUBADDR_NETBYTES = (42, 63, 36)
INTADDRR_NETBYTES = (19, 54, 25)

PRIO_UNIMPORTANT = 1
PRIO_NORMAL = 2
PRIO_ELEVATED = 3
PRIO_PRIORITY = 4



class MoneroException(Exception):
    pass

class BackendException(MoneroException):
    pass

class NoDaemonConnection(BackendException):
    pass

class AccountException(MoneroException):
    pass

class WrongAddress(AccountException):
    pass

class WrongPaymentId(AccountException):
    pass

class NotEnoughMoney(AccountException):
    pass

class NotEnoughUnlockedMoney(NotEnoughMoney):
    pass

class AmountIsZero(AccountException):
    pass

class TransactionNotPossible(AccountException):
    pass

class TransactionBroadcastError(BackendException):
    def __init__(self, message, details=None):
        self.details = details
        super(TransactionBroadcastError, self).__init__(message)

class TransactionNotFound(AccountException):
    pass

class SignatureCheckFailed(MoneroException):
    pass

class WalletIsNotDeterministic(MoneroException):
    pass

class GenericTransferError(AccountException):
    pass

class AccountIndexOutOfBound(AccountException):
    pass

class AddressIndexOutOfBound(AccountException):
    pass

class WalletIsWatchOnly(MoneroException):
    pass



import operator
import six
from .transaction import Transaction


class Block(object):
    """
    A Monero block. Identified by `hash` (optionaly by `height`).

    This class is not intended to be turned into objects by the user,
    it is used by backends.
    """
    hash = None
    height = None
    timestamp = None
    version = None
    difficulty = None
    nonce = None
    orphan = False
    prev_hash = None
    reward = None
    blob = None

    transactions = None

    def __init__(self, **kwargs):
        for k in ('hash', 'height', 'timestamp', 'version', 'difficulty', 'nonce', 'prev_hash', 'reward'):
            setattr(self, k, kwargs.get(k, getattr(self, k)))
        self.orphan = kwargs.get('orphan', self.orphan)
        self.transactions = kwargs.get('transactions', self.transactions or [])
        self.blob = kwargs.get('blob', self.blob)

    def __eq__(self, other):
        if isinstance(other, Block):
            return self.hash == other.hash
        elif isinstance(other, six.string_types):
            return six.ensure_text(self.hash) == six.ensure_text(other)
        return super(Block, self).__eq__(other)

    def __contains__(self, tx):
        if isinstance(tx, six.string_types):
            txid = tx
        elif isinstance(tx, Transaction):
            txid = tx.hash
        else:
            raise ValueError(
                "Only Transaction or hash strings may be used to test existence in Blocks, "
                "got '{:s}'".format(tx))
        return txid in map(operator.attrgetter('hash'), self.transactions)



from .wordlist import get_wordlist, list_wordlists
from .english import English

from .chinese_simplified import ChineseSimplified
from .dutch import Dutch
from .esperanto import Esperanto
from .french import French
from .german import German
from .italian import Italian
from .japanese import Japanese
from .lojban import Lojban
from .portuguese import Portuguese
from .russian import Russian
from .spanish import Spanish



#!/usr/bin/env python
# -*- coding: utf-8 -*-
#
# Word list originally created by dabura667 and released under The MIT License (MIT)
#
# The MIT License (MIT)
#
# Permission is hereby granted, free of charge, to any person obtaining
# a copy of this software and associated documentation files (the
# "Software"), to deal in the Software without restriction, including
# without limitation the rights to use, copy, modify, merge, publish,
# distribute, sublicense, and/or sell copies of the Software, and to
# permit persons to whom the Software is furnished to do so, subject to
# the following conditions:
#
# The above copyright notice and this permission notice shall be
# included in all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
# MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
# NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
# LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
# OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
# WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
#
# Code surrounding the word list is Copyright (c) 2014-2018, The Monero Project
#
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without modification, are
# permitted provided that the following conditions are met:
#
# 1. Redistributions of source code must retain the above copyright notice, this list of
#    conditions and the following disclaimer.
#
# 2. Redistributions in binary form must reproduce the above copyright notice, this list
#    of conditions and the following disclaimer in the documentation and/or other
#    materials provided with the distribution.
#
# 3. Neither the name of the copyright holder nor the names of its contributors may be
#    used to endorse or promote products derived from this software without specific
#    prior written permission.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY
# EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
# MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL
# THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
# SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
# PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
# INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
# STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF
# THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
#
# list of words from:
#     https://github.com/monero-project/monero/blob/master/src/mnemonics/lojban.h
#     Most recent commit: 8ea3c4d54429976e9001b8cc4868b721e6747e3c


from .wordlist import Wordlist

class Lojban(Wordlist):
    language_name = "Lojban"
    english_language_name = "Lojban"
    unique_prefix_length = 4
    word_list = [
        "backi",
        "bacru",
        "badna",
        "badri",
        "bajra",
        "bakfu",
        "bakni",
        "bakri",
        "baktu",
        "balji",
        "balni",
        "balre",
        "balvi",
        "bambu",
        "bancu",
        "bandu",
        "banfi",
        "bangu",
        "banli",
        "banro",
        "banxa",
        "banzu",
        "bapli",
        "barda",
        "bargu",
        "barja",
        "barna",
        "bartu",
        "basfa",
        "basna",
        "basti",
        "batci",
        "batke",
        "bavmi",
        "baxso",
        "bebna",
        "bekpi",
        "bemro",
        "bende",
        "bengo",
        "benji",
        "benre",
        "benzo",
        "bergu",
        "bersa",
        "berti",
        "besna",
        "besto",
        "betfu",
        "betri",
        "bevri",
        "bidju",
        "bifce",
        "bikla",
        "bilga",
        "bilma",
        "bilni",
        "bindo",
        "binra",
        "binxo",
        "birje",
        "birka",
        "birti",
        "bisli",
        "bitmu",
        "bitni",
        "blabi",
        "blaci",
        "blanu",
        "bliku",
        "bloti",
        "bolci",
        "bongu",
        "boske",
        "botpi",
        "boxfo",
        "boxna",
        "bradi",
        "brano",
        "bratu",
        "brazo",
        "bredi",
        "bridi",
        "brife",
        "briju",
        "brito",
        "brivo",
        "broda",
        "bruna",
        "budjo",
        "bukpu",
        "bumru",
        "bunda",
        "bunre",
        "burcu",
        "burna",
        "cabna",
        "cabra",
        "cacra",
        "cadga",
        "cadzu",
        "cafne",
        "cagna",
        "cakla",
        "calku",
        "calse",
        "canci",
        "cando",
        "cange",
        "canja",
        "canko",
        "canlu",
        "canpa",
        "canre",
        "canti",
        "carce",
        "carfu",
        "carmi",
        "carna",
        "cartu",
        "carvi",
        "casnu",
        "catke",
        "catlu",
        "catni",
        "catra",
        "caxno",
        "cecla",
        "cecmu",
        "cedra",
        "cenba",
        "censa",
        "centi",
        "cerda",
        "cerni",
        "certu",
        "cevni",
        "cfale",
        "cfari",
        "cfika",
        "cfila",
        "cfine",
        "cfipu",
        "ciblu",
        "cicna",
        "cidja",
        "cidni",
        "cidro",
        "cifnu",
        "cigla",
        "cikna",
        "cikre",
        "ciksi",
        "cilce",
        "cilfu",
        "cilmo",
        "cilre",
        "cilta",
        "cimde",
        "cimni",
        "cinba",
        "cindu",
        "cinfo",
        "cinje",
        "cinki",
        "cinla",
        "cinmo",
        "cinri",
        "cinse",
        "cinta",
        "cinza",
        "cipni",
        "cipra",
        "cirko",
        "cirla",
        "ciska",
        "cisma",
        "cisni",
        "ciste",
        "citka",
        "citno",
        "citri",
        "citsi",
        "civla",
        "cizra",
        "ckabu",
        "ckafi",
        "ckaji",
        "ckana",
        "ckape",
        "ckasu",
        "ckeji",
        "ckiku",
        "ckilu",
        "ckini",
        "ckire",
        "ckule",
        "ckunu",
        "cladu",
        "clani",
        "claxu",
        "cletu",
        "clika",
        "clinu",
        "clira",
        "clite",
        "cliva",
        "clupa",
        "cmaci",
        "cmalu",
        "cmana",
        "cmavo",
        "cmene",
        "cmeta",
        "cmevo",
        "cmila",
        "cmima",
        "cmoni",
        "cnano",
        "cnebo",
        "cnemu",
        "cnici",
        "cnino",
        "cnisa",
        "cnita",
        "cokcu",
        "condi",
        "conka",
        "corci",
        "cortu",
        "cpacu",
        "cpana",
        "cpare",
        "cpedu",
        "cpina",
        "cradi",
        "crane",
        "creka",
        "crepu",
        "cribe",
        "crida",
        "crino",
        "cripu",
        "crisa",
        "critu",
        "ctaru",
        "ctebi",
        "cteki",
        "ctile",
        "ctino",
        "ctuca",
        "cukla",
        "cukre",
        "cukta",
        "culno",
        "cumki",
        "cumla",
        "cunmi",
        "cunso",
        "cuntu",
        "cupra",
        "curmi",
        "curnu",
        "curve",
        "cusku",
        "cusna",
        "cutci",
        "cutne",
        "cuxna",
        "dacru",
        "dacti",
        "dadjo",
        "dakfu",
        "dakli",
        "damba",
        "damri",
        "dandu",
        "danfu",
        "danlu",
        "danmo",
        "danre",
        "dansu",
        "danti",
        "daplu",
        "dapma",
        "darca",
        "dargu",
        "darlu",
        "darno",
        "darsi",
        "darxi",
        "daski",
        "dasni",
        "daspo",
        "dasri",
        "datka",
        "datni",
        "datro",
        "decti",
        "degji",
        "dejni",
        "dekpu",
        "dekto",
        "delno",
        "dembi",
        "denci",
        "denmi",
        "denpa",
        "dertu",
        "derxi",
        "desku",
        "detri",
        "dicma",
        "dicra",
        "didni",
        "digno",
        "dikca",
        "diklo",
        "dikni",
        "dilcu",
        "dilma",
        "dilnu",
        "dimna",
        "dindi",
        "dinju",
        "dinko",
        "dinso",
        "dirba",
        "dirce",
        "dirgo",
        "disko",
        "ditcu",
        "divzi",
        "dizlo",
        "djacu",
        "djedi",
        "djica",
        "djine",
        "djuno",
        "donri",
        "dotco",
        "draci",
        "drani",
        "drata",
        "drudi",
        "dugri",
        "dukse",
        "dukti",
        "dunda",
        "dunja",
        "dunku",
        "dunli",
        "dunra",
        "dutso",
        "dzena",
        "dzipo",
        "facki",
        "fadni",
        "fagri",
        "falnu",
        "famti",
        "fancu",
        "fange",
        "fanmo",
        "fanri",
        "fanta",
        "fanva",
        "fanza",
        "fapro",
        "farka",
        "farlu",
        "farna",
        "farvi",
        "fasnu",
        "fatci",
        "fatne",
        "fatri",
        "febvi",
        "fegli",
        "femti",
        "fendi",
        "fengu",
        "fenki",
        "fenra",
        "fenso",
        "fepni",
        "fepri",
        "ferti",
        "festi",
        "fetsi",
        "figre",
        "filso",
        "finpe",
        "finti",
        "firca",
        "fisli",
        "fizbu",
        "flaci",
        "flalu",
        "flani",
        "flecu",
        "flese",
        "fliba",
        "flira",
        "foldi",
        "fonmo",
        "fonxa",
        "forca",
        "forse",
        "fraso",
        "frati",
        "fraxu",
        "frica",
        "friko",
        "frili",
        "frinu",
        "friti",
        "frumu",
        "fukpi",
        "fulta",
        "funca",
        "fusra",
        "fuzme",
        "gacri",
        "gadri",
        "galfi",
        "galtu",
        "galxe",
        "ganlo",
        "ganra",
        "ganse",
        "ganti",
        "ganxo",
        "ganzu",
        "gapci",
        "gapru",
        "garna",
        "gasnu",
        "gaspo",
        "gasta",
        "genja",
        "gento",
        "genxu",
        "gerku",
        "gerna",
        "gidva",
        "gigdo",
        "ginka",
        "girzu",
        "gismu",
        "glare",
        "gleki",
        "gletu",
        "glico",
        "glife",
        "glosa",
        "gluta",
        "gocti",
        "gomsi",
        "gotro",
        "gradu",
        "grafu",
        "grake",
        "grana",
        "grasu",
        "grava",
        "greku",
        "grusi",
        "grute",
        "gubni",
        "gugde",
        "gugle",
        "gumri",
        "gundi",
        "gunka",
        "gunma",
        "gunro",
        "gunse",
        "gunta",
        "gurni",
        "guska",
        "gusni",
        "gusta",
        "gutci",
        "gutra",
        "guzme",
        "jabre",
        "jadni",
        "jakne",
        "jalge",
        "jalna",
        "jalra",
        "jamfu",
        "jamna",
        "janbe",
        "janco",
        "janli",
        "jansu",
        "janta",
        "jarbu",
        "jarco",
        "jarki",
        "jaspu",
        "jatna",
        "javni",
        "jbama",
        "jbari",
        "jbena",
        "jbera",
        "jbini",
        "jdari",
        "jdice",
        "jdika",
        "jdima",
        "jdini",
        "jduli",
        "jecta",
        "jeftu",
        "jegvo",
        "jelca",
        "jemna",
        "jenca",
        "jendu",
        "jenmi",
        "jensi",
        "jerna",
        "jersi",
        "jerxo",
        "jesni",
        "jetce",
        "jetnu",
        "jgalu",
        "jganu",
        "jgari",
        "jgena",
        "jgina",
        "jgira",
        "jgita",
        "jibni",
        "jibri",
        "jicla",
        "jicmu",
        "jijnu",
        "jikca",
        "jikfi",
        "jikni",
        "jikru",
        "jilka",
        "jilra",
        "jimca",
        "jimpe",
        "jimte",
        "jinci",
        "jinda",
        "jinga",
        "jinku",
        "jinme",
        "jinru",
        "jinsa",
        "jinto",
        "jinvi",
        "jinzi",
        "jipci",
        "jipno",
        "jirna",
        "jisra",
        "jitfa",
        "jitro",
        "jivbu",
        "jivna",
        "jmaji",
        "jmifa",
        "jmina",
        "jmive",
        "jonse",
        "jordo",
        "jorne",
        "jubme",
        "judri",
        "jufra",
        "jukni",
        "jukpa",
        "julne",
        "julro",
        "jundi",
        "jungo",
        "junla",
        "junri",
        "junta",
        "jurme",
        "jursa",
        "jutsi",
        "juxre",
        "jvinu",
        "jviso",
        "kabri",
        "kacma",
        "kadno",
        "kafke",
        "kagni",
        "kajde",
        "kajna",
        "kakne",
        "kakpa",
        "kalci",
        "kalri",
        "kalsa",
        "kalte",
        "kamju",
        "kamni",
        "kampu",
        "kamre",
        "kanba",
        "kancu",
        "kandi",
        "kanji",
        "kanla",
        "kanpe",
        "kanro",
        "kansa",
        "kantu",
        "kanxe",
        "karbi",
        "karce",
        "karda",
        "kargu",
        "karli",
        "karni",
        "katci",
        "katna",
        "kavbu",
        "kazra",
        "kecti",
        "kekli",
        "kelci",
        "kelvo",
        "kenka",
        "kenra",
        "kensa",
        "kerfa",
        "kerlo",
        "kesri",
        "ketco",
        "ketsu",
        "kevna",
        "kibro",
        "kicne",
        "kijno",
        "kilto",
        "kinda",
        "kinli",
        "kisto",
        "klaji",
        "klaku",
        "klama",
        "klani",
        "klesi",
        "kliki",
        "klina",
        "kliru",
        "kliti",
        "klupe",
        "kluza",
        "kobli",
        "kogno",
        "kojna",
        "kokso",
        "kolme",
        "komcu",
        "konju",
        "korbi",
        "korcu",
        "korka",
        "korvo",
        "kosmu",
        "kosta",
        "krali",
        "kramu",
        "krasi",
        "krati",
        "krefu",
        "krici",
        "krili",
        "krinu",
        "krixa",
        "kruca",
        "kruji",
        "kruvi",
        "kubli",
        "kucli",
        "kufra",
        "kukte",
        "kulnu",
        "kumfa",
        "kumte",
        "kunra",
        "kunti",
        "kurfa",
        "kurji",
        "kurki",
        "kuspe",
        "kusru",
        "labno",
        "lacni",
        "lacpu",
        "lacri",
        "ladru",
        "lafti",
        "lakne",
        "lakse",
        "laldo",
        "lalxu",
        "lamji",
        "lanbi",
        "lanci",
        "landa",
        "lanka",
        "lanli",
        "lanme",
        "lante",
        "lanxe",
        "lanzu",
        "larcu",
        "larva",
        "lasna",
        "lastu",
        "latmo",
        "latna",
        "lazni",
        "lebna",
        "lelxe",
        "lenga",
        "lenjo",
        "lenku",
        "lerci",
        "lerfu",
        "libjo",
        "lidne",
        "lifri",
        "lijda",
        "limfa",
        "limna",
        "lince",
        "lindi",
        "linga",
        "linji",
        "linsi",
        "linto",
        "lisri",
        "liste",
        "litce",
        "litki",
        "litru",
        "livga",
        "livla",
        "logji",
        "loglo",
        "lojbo",
        "loldi",
        "lorxu",
        "lubno",
        "lujvo",
        "luksi",
        "lumci",
        "lunbe",
        "lunra",
        "lunsa",
        "luska",
        "lusto",
        "mabla",
        "mabru",
        "macnu",
        "majga",
        "makcu",
        "makfa",
        "maksi",
        "malsi",
        "mamta",
        "manci",
        "manfo",
        "mango",
        "manku",
        "manri",
        "mansa",
        "manti",
        "mapku",
        "mapni",
        "mapra",
        "mapti",
        "marbi",
        "marce",
        "marde",
        "margu",
        "marji",
        "marna",
        "marxa",
        "masno",
        "masti",
        "matci",
        "matli",
        "matne",
        "matra",
        "mavji",
        "maxri",
        "mebri",
        "megdo",
        "mekso",
        "melbi",
        "meljo",
        "melmi",
        "menli",
        "menre",
        "mensi",
        "mentu",
        "merko",
        "merli",
        "metfo",
        "mexno",
        "midju",
        "mifra",
        "mikce",
        "mikri",
        "milti",
        "milxe",
        "minde",
        "minji",
        "minli",
        "minra",
        "mintu",
        "mipri",
        "mirli",
        "misno",
        "misro",
        "mitre",
        "mixre",
        "mlana",
        "mlatu",
        "mleca",
        "mledi",
        "mluni",
        "mogle",
        "mokca",
        "moklu",
        "molki",
        "molro",
        "morji",
        "morko",
        "morna",
        "morsi",
        "mosra",
        "mraji",
        "mrilu",
        "mruli",
        "mucti",
        "mudri",
        "mugle",
        "mukti",
        "mulno",
        "munje",
        "mupli",
        "murse",
        "murta",
        "muslo",
        "mutce",
        "muvdu",
        "muzga",
        "nabmi",
        "nakni",
        "nalci",
        "namcu",
        "nanba",
        "nanca",
        "nandu",
        "nanla",
        "nanmu",
        "nanvi",
        "narge",
        "narju",
        "natfe",
        "natmi",
        "natsi",
        "navni",
        "naxle",
        "nazbi",
        "nejni",
        "nelci",
        "nenri",
        "nerde",
        "nibli",
        "nicfa",
        "nicte",
        "nikle",
        "nilce",
        "nimre",
        "ninja",
        "ninmu",
        "nirna",
        "nitcu",
        "nivji",
        "nixli",
        "nobli",
        "norgo",
        "notci",
        "nudle",
        "nukni",
        "nunmu",
        "nupre",
        "nurma",
        "nusna",
        "nutka",
        "nutli",
        "nuzba",
        "nuzlo",
        "pacna",
        "pagbu",
        "pagre",
        "pajni",
        "palci",
        "palku",
        "palma",
        "palne",
        "palpi",
        "palta",
        "pambe",
        "pamga",
        "panci",
        "pandi",
        "panje",
        "panka",
        "panlo",
        "panpi",
        "panra",
        "pante",
        "panzi",
        "papri",
        "parbi",
        "pardu",
        "parji",
        "pastu",
        "patfu",
        "patlu",
        "patxu",
        "paznu",
        "pelji",
        "pelxu",
        "pemci",
        "penbi",
        "pencu",
        "pendo",
        "penmi",
        "pensi",
        "pentu",
        "perli",
        "pesxu",
        "petso",
        "pevna",
        "pezli",
        "picti",
        "pijne",
        "pikci",
        "pikta",
        "pilda",
        "pilji",
        "pilka",
        "pilno",
        "pimlu",
        "pinca",
        "pindi",
        "pinfu",
        "pinji",
        "pinka",
        "pinsi",
        "pinta",
        "pinxe",
        "pipno",
        "pixra",
        "plana",
        "platu",
        "pleji",
        "plibu",
        "plini",
        "plipe",
        "plise",
        "plita",
        "plixa",
        "pluja",
        "pluka",
        "pluta",
        "pocli",
        "polje",
        "polno",
        "ponjo",
        "ponse",
        "poplu",
        "porpi",
        "porsi",
        "porto",
        "prali",
        "prami",
        "prane",
        "preja",
        "prenu",
        "preri",
        "preti",
        "prije",
        "prina",
        "pritu",
        "proga",
        "prosa",
        "pruce",
        "pruni",
        "pruri",
        "pruxi",
        "pulce",
        "pulji",
        "pulni",
        "punji",
        "punli",
        "pupsu",
        "purci",
        "purdi",
        "purmo",
        "racli",
        "ractu",
        "radno",
        "rafsi",
        "ragbi",
        "ragve",
        "rakle",
        "rakso",
        "raktu",
        "ralci",
        "ralju",
        "ralte",
        "randa",
        "rango",
        "ranji",
        "ranmi",
        "ransu",
        "ranti",
        "ranxi",
        "rapli",
        "rarna",
        "ratcu",
        "ratni",
        "rebla",
        "rectu",
        "rekto",
        "remna",
        "renro",
        "renvi",
        "respa",
        "rexsa",
        "ricfu",
        "rigni",
        "rijno",
        "rilti",
        "rimni",
        "rinci",
        "rindo",
        "rinju",
        "rinka",
        "rinsa",
        "rirci",
        "rirni",
        "rirxe",
        "rismi",
        "risna",
        "ritli",
        "rivbi",
        "rokci",
        "romge",
        "romlo",
        "ronte",
        "ropno",
        "rorci",
        "rotsu",
        "rozgu",
        "ruble",
        "rufsu",
        "runme",
        "runta",
        "rupnu",
        "rusko",
        "rutni",
        "sabji",
        "sabnu",
        "sacki",
        "saclu",
        "sadjo",
        "sakci",
        "sakli",
        "sakta",
        "salci",
        "salpo",
        "salri",
        "salta",
        "samcu",
        "sampu",
        "sanbu",
        "sance",
        "sanga",
        "sanji",
        "sanli",
        "sanmi",
        "sanso",
        "santa",
        "sarcu",
        "sarji",
        "sarlu",
        "sarni",
        "sarxe",
        "saske",
        "satci",
        "satre",
        "savru",
        "sazri",
        "sefsi",
        "sefta",
        "sekre",
        "selci",
        "selfu",
        "semto",
        "senci",
        "sengi",
        "senpi",
        "senta",
        "senva",
        "sepli",
        "serti",
        "sesre",
        "setca",
        "sevzi",
        "sfani",
        "sfasa",
        "sfofa",
        "sfubu",
        "sibli",
        "siclu",
        "sicni",
        "sicpi",
        "sidbo",
        "sidju",
        "sigja",
        "sigma",
        "sikta",
        "silka",
        "silna",
        "simlu",
        "simsa",
        "simxu",
        "since",
        "sinma",
        "sinso",
        "sinxa",
        "sipna",
        "sirji",
        "sirxo",
        "sisku",
        "sisti",
        "sitna",
        "sivni",
        "skaci",
        "skami",
        "skapi",
        "skari",
        "skicu",
        "skiji",
        "skina",
        "skori",
        "skoto",
        "skuba",
        "skuro",
        "slabu",
        "slaka",
        "slami",
        "slanu",
        "slari",
        "slasi",
        "sligu",
        "slilu",
        "sliri",
        "slovo",
        "sluji",
        "sluni",
        "smacu",
        "smadi",
        "smaji",
        "smaka",
        "smani",
        "smela",
        "smoka",
        "smuci",
        "smuni",
        "smusu",
        "snada",
        "snanu",
        "snidu",
        "snime",
        "snipa",
        "snuji",
        "snura",
        "snuti",
        "sobde",
        "sodna",
        "sodva",
        "softo",
        "solji",
        "solri",
        "sombo",
        "sonci",
        "sorcu",
        "sorgu",
        "sorni",
        "sorta",
        "sovda",
        "spaji",
        "spali",
        "spano",
        "spati",
        "speni",
        "spero",
        "spisa",
        "spita",
        "spofu",
        "spoja",
        "spuda",
        "sputu",
        "sraji",
        "sraku",
        "sralo",
        "srana",
        "srasu",
        "srera",
        "srito",
        "sruma",
        "sruri",
        "stace",
        "stagi",
        "staku",
        "stali",
        "stani",
        "stapa",
        "stasu",
        "stati",
        "steba",
        "steci",
        "stedu",
        "stela",
        "stero",
        "stici",
        "stidi",
        "stika",
        "stizu",
        "stodi",
        "stuna",
        "stura",
        "stuzi",
        "sucta",
        "sudga",
        "sufti",
        "suksa",
        "sumji",
        "sumne",
        "sumti",
        "sunga",
        "sunla",
        "surla",
        "sutra",
        "tabno",
        "tabra",
        "tadji",
        "tadni",
        "tagji",
        "taksi",
        "talsa",
        "tamca",
        "tamji",
        "tamne",
        "tanbo",
        "tance",
        "tanjo",
        "tanko",
        "tanru",
        "tansi",
        "tanxe",
        "tapla",
        "tarbi",
        "tarci",
        "tarla",
        "tarmi",
        "tarti",
        "taske",
        "tasmi",
        "tasta",
        "tatpi",
        "tatru",
        "tavla",
        "taxfu",
        "tcaci",
        "tcadu",
        "tcana",
        "tcati",
        "tcaxe",
        "tcena",
        "tcese",
        "tcica",
        "tcidu",
        "tcika",
        "tcila",
        "tcima",
        "tcini",
        "tcita",
        "temci",
        "temse",
        "tende",
        "tenfa",
        "tengu",
        "terdi",
        "terpa",
        "terto",
        "tifri",
        "tigni",
        "tigra",
        "tikpa",
        "tilju",
        "tinbe",
        "tinci",
        "tinsa",
        "tirna",
        "tirse",
        "tirxu",
        "tisna",
        "titla",
        "tivni",
        "tixnu",
        "toknu",
        "toldi",
        "tonga",
        "tordu",
        "torni",
        "torso",
        "traji",
        "trano",
        "trati",
        "trene",
        "tricu",
        "trina",
        "trixe",
        "troci",
        "tsaba",
        "tsali",
        "tsani",
        "tsapi",
        "tsiju",
        "tsina",
        "tsuku",
        "tubnu",
        "tubra",
        "tugni",
        "tujli",
        "tumla",
        "tunba",
        "tunka",
        "tunlo",
        "tunta",
        "tuple",
        "turko",
        "turni",
        "tutci",
        "tutle",
        "tutra",
        "vacri",
        "vajni",
        "valsi",
        "vamji",
        "vamtu",
        "vanbi",
        "vanci",
        "vanju",
        "vasru",
        "vasxu",
        "vecnu",
        "vedli",
        "venfu",
        "vensa",
        "vente",
        "vepre",
        "verba",
        "vibna",
        "vidni",
        "vidru",
        "vifne",
        "vikmi",
        "viknu",
        "vimcu",
        "vindu",
        "vinji",
        "vinta",
        "vipsi",
        "virnu",
        "viska",
        "vitci",
        "vitke",
        "vitno",
        "vlagi",
        "vlile",
        "vlina",
        "vlipa",
        "vofli",
        "voksa",
        "volve",
        "vorme",
        "vraga",
        "vreji",
        "vreta",
        "vrici",
        "vrude",
        "vrusi",
        "vubla",
        "vujnu",
        "vukna",
        "vukro",
        "xabju",
        "xadba",
        "xadji",
        "xadni",
        "xagji",
        "xagri",
        "xajmi",
        "xaksu",
        "xalbo",
        "xalka",
        "xalni",
        "xamgu",
        "xampo",
        "xamsi",
        "xance",
        "xango",
        "xanka",
        "xanri",
        "xansa",
        "xanto",
        "xarci",
        "xarju",
        "xarnu",
        "xasli",
        "xasne",
        "xatra",
        "xatsi",
        "xazdo",
        "xebni",
        "xebro",
        "xecto",
        "xedja",
        "xekri",
        "xelso",
        "xendo",
        "xenru",
        "xexso",
        "xigzo",
        "xindo",
        "xinmo",
        "xirma",
        "xislu",
        "xispo",
        "xlali",
        "xlura",
        "xorbo",
        "xorlo",
        "xotli",
        "xrabo",
        "xrani",
        "xriso",
        "xrotu",
        "xruba",
        "xruki",
        "xrula",
        "xruti",
        "xukmi",
        "xulta",
        "xunre",
        "xurdo",
        "xusra",
        "xutla",
        "zabna",
        "zajba",
        "zalvi",
        "zanru",
        "zarci",
        "zargu",
        "zasni",
        "zasti",
        "zbabu",
        "zbani",
        "zbasu",
        "zbepi",
        "zdani",
        "zdile",
        "zekri",
        "zenba",
        "zepti",
        "zetro",
        "zevla",
        "zgadi",
        "zgana",
        "zgike",
        "zifre",
        "zinki",
        "zirpu",
        "zivle",
        "zmadu",
        "zmiku",
        "zucna",
        "zukte",
        "zumri",
        "zungi",
        "zunle",
        "zunti",
        "zutse",
        "zvati",
        "zviki",
        "jbobau",
        "jbopre",
        "karsna",
        "cabdei",
        "zunsna",
        "gendra",
        "glibau",
        "nintadni",
        "pavyseljirna",
        "vlaste",
        "selbri",
        "latro'a",
        "zdakemkulgu'a",
        "mriste",
        "selsku",
        "fu'ivla",
        "tolmo'i",
        "snavei",
        "xagmau",
        "retsku",
        "ckupau",
        "skudji",
        "smudra",
        "prulamdei",
        "vokta'a",
        "tinju'i",
        "jefyfa'o",
        "bavlamdei",
        "kinzga",
        "jbocre",
        "jbovla",
        "xauzma",
        "selkei",
        "xuncku",
        "spusku",
        "jbogu'e",
        "pampe'o",
        "bripre",
        "jbosnu",
        "zi'evla",
        "gimste",
        "tolzdi",
        "velski",
        "samselpla",
        "cnegau",
        "velcki",
        "selja'e",
        "fasybau",
        "zanfri",
        "reisku",
        "favgau",
        "jbota'a",
        "rejgau",
        "malgli",
        "zilkai",
        "keidji",
        "tersu'i",
        "jbofi'e",
        "cnima'o",
        "mulgau",
        "ningau",
        "ponbau",
        "mrobi'o",
        "rarbau",
        "zmanei",
        "famyma'o",
        "vacysai",
        "jetmlu",
        "jbonunsla",
        "nunpe'i",
        "fa'orma'o",
        "crezenzu'e",
        "jbojbe",
        "cmicu'a",
        "zilcmi",
        "tolcando",
        "zukcfu",
        "depybu'i",
        "mencre",
        "matmau",
        "nunctu",
        "selma'o",
        "titnanba",
        "naldra",
        "jvajvo",
        "nunsnu",
        "nerkla",
        "cimjvo",
        "muvgau",
        "zipcpi",
        "runbau",
        "faumlu",
        "terbri",
        "balcu'e",
        "dragau",
        "smuvelcki",
        "piksku",
        "selpli",
        "bregau",
        "zvafa'i",
        "ci'izra",
        "noltruti'u",
        "samtci",
        "snaxa'a",
    ]



#!/usr/bin/env python
# -*- coding: utf-8 -*-
#
# Word list originally created by dabura667 and released under The MIT License (MIT)
#
# The MIT License (MIT)
#
# Permission is hereby granted, free of charge, to any person obtaining
# a copy of this software and associated documentation files (the
# "Software"), to deal in the Software without restriction, including
# without limitation the rights to use, copy, modify, merge, publish,
# distribute, sublicense, and/or sell copies of the Software, and to
# permit persons to whom the Software is furnished to do so, subject to
# the following conditions:
#
# The above copyright notice and this permission notice shall be
# included in all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
# MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
# NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
# LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
# OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
# WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
#
# Code surrounding the word list is Copyright (c) 2014-2018, The Monero Project
#
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without modification, are
# permitted provided that the following conditions are met:
#
# 1. Redistributions of source code must retain the above copyright notice, this list of
#    conditions and the following disclaimer.
#
# 2. Redistributions in binary form must reproduce the above copyright notice, this list
#    of conditions and the following disclaimer in the documentation and/or other
#    materials provided with the distribution.
#
# 3. Neither the name of the copyright holder nor the names of its contributors may be
#    used to endorse or promote products derived from this software without specific
#    prior written permission.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY
# EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
# MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL
# THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
# SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
# PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
# INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
# STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF
# THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
#
# list of words from:
#     https://github.com/monero-project/monero/blob/master/src/mnemonics/italian.h
#     Most recent commit: 8ea3c4d54429976e9001b8cc4868b721e6747e3c


from .wordlist import Wordlist


class Italian(Wordlist):
    language_name = "Italiano"
    english_language_name = "Italian"
    unique_prefix_length = 4
    word_list = [
        "abbinare",
        "abbonato",
        "abisso",
        "abitare",
        "abominio",
        "accadere",
        "accesso",
        "acciaio",
        "accordo",
        "accumulo",
        "acido",
        "acqua",
        "acrobata",
        "acustico",
        "adattare",
        "addetto",
        "addio",
        "addome",
        "adeguato",
        "aderire",
        "adorare",
        "adottare",
        "adozione",
        "adulto",
        "aereo",
        "aerobica",
        "affare",
        "affetto",
        "affidare",
        "affogato",
        "affronto",
        "africano",
        "afrodite",
        "agenzia",
        "aggancio",
        "aggeggio",
        "aggiunta",
        "agio",
        "agire",
        "agitare",
        "aglio",
        "agnello",
        "agosto",
        "aiutare",
        "albero",
        "albo",
        "alce",
        "alchimia",
        "alcool",
        "alfabeto",
        "algebra",
        "alimento",
        "allarme",
        "alleanza",
        "allievo",
        "alloggio",
        "alluce",
        "alpi",
        "alterare",
        "altro",
        "aluminio",
        "amante",
        "amarezza",
        "ambiente",
        "ambrosia",
        "america",
        "amico",
        "ammalare",
        "ammirare",
        "amnesia",
        "amnistia",
        "amore",
        "ampliare",
        "amputare",
        "analisi",
        "anamnesi",
        "ananas",
        "anarchia",
        "anatra",
        "anca",
        "ancorato",
        "andare",
        "androide",
        "aneddoto",
        "anello",
        "angelo",
        "angolino",
        "anguilla",
        "anidride",
        "anima",
        "annegare",
        "anno",
        "annuncio",
        "anomalia",
        "antenna",
        "anticipo",
        "aperto",
        "apostolo",
        "appalto",
        "appello",
        "appiglio",
        "applauso",
        "appoggio",
        "appurare",
        "aprile",
        "aquila",
        "arabo",
        "arachidi",
        "aragosta",
        "arancia",
        "arbitrio",
        "archivio",
        "arco",
        "argento",
        "argilla",
        "aria",
        "ariete",
        "arma",
        "armonia",
        "aroma",
        "arrivare",
        "arrosto",
        "arsenale",
        "arte",
        "artiglio",
        "asfalto",
        "asfissia",
        "asino",
        "asparagi",
        "aspirina",
        "assalire",
        "assegno",
        "assolto",
        "assurdo",
        "asta",
        "astratto",
        "atlante",
        "atletica",
        "atomo",
        "atropina",
        "attacco",
        "attesa",
        "attico",
        "atto",
        "attrarre",
        "auguri",
        "aula",
        "aumento",
        "aurora",
        "auspicio",
        "autista",
        "auto",
        "autunno",
        "avanzare",
        "avarizia",
        "avere",
        "aviatore",
        "avido",
        "avorio",
        "avvenire",
        "avviso",
        "avvocato",
        "azienda",
        "azione",
        "azzardo",
        "azzurro",
        "babbuino",
        "bacio",
        "badante",
        "baffi",
        "bagaglio",
        "bagliore",
        "bagno",
        "balcone",
        "balena",
        "ballare",
        "balordo",
        "balsamo",
        "bambola",
        "bancomat",
        "banda",
        "barato",
        "barba",
        "barista",
        "barriera",
        "basette",
        "basilico",
        "bassista",
        "bastare",
        "battello",
        "bavaglio",
        "beccare",
        "beduino",
        "bellezza",
        "bene",
        "benzina",
        "berretto",
        "bestia",
        "bevitore",
        "bianco",
        "bibbia",
        "biberon",
        "bibita",
        "bici",
        "bidone",
        "bilancia",
        "biliardo",
        "binario",
        "binocolo",
        "biologia",
        "biondina",
        "biopsia",
        "biossido",
        "birbante",
        "birra",
        "biscotto",
        "bisogno",
        "bistecca",
        "bivio",
        "blindare",
        "bloccare",
        "bocca",
        "bollire",
        "bombola",
        "bonifico",
        "borghese",
        "borsa",
        "bottino",
        "botulino",
        "braccio",
        "bradipo",
        "branco",
        "bravo",
        "bresaola",
        "bretelle",
        "brevetto",
        "briciola",
        "brigante",
        "brillare",
        "brindare",
        "brivido",
        "broccoli",
        "brontolo",
        "bruciare",
        "brufolo",
        "bucare",
        "buddista",
        "budino",
        "bufera",
        "buffo",
        "bugiardo",
        "buio",
        "buono",
        "burrone",
        "bussola",
        "bustina",
        "buttare",
        "cabernet",
        "cabina",
        "cacao",
        "cacciare",
        "cactus",
        "cadavere",
        "caffe",
        "calamari",
        "calcio",
        "caldaia",
        "calmare",
        "calunnia",
        "calvario",
        "calzone",
        "cambiare",
        "camera",
        "camion",
        "cammello",
        "campana",
        "canarino",
        "cancello",
        "candore",
        "cane",
        "canguro",
        "cannone",
        "canoa",
        "cantare",
        "canzone",
        "caos",
        "capanna",
        "capello",
        "capire",
        "capo",
        "capperi",
        "capra",
        "capsula",
        "caraffa",
        "carbone",
        "carciofo",
        "cardigan",
        "carenza",
        "caricare",
        "carota",
        "carrello",
        "carta",
        "casa",
        "cascare",
        "caserma",
        "cashmere",
        "casino",
        "cassetta",
        "castello",
        "catalogo",
        "catena",
        "catorcio",
        "cattivo",
        "causa",
        "cauzione",
        "cavallo",
        "caverna",
        "caviglia",
        "cavo",
        "cazzotto",
        "celibato",
        "cemento",
        "cenare",
        "centrale",
        "ceramica",
        "cercare",
        "ceretta",
        "cerniera",
        "certezza",
        "cervello",
        "cessione",
        "cestino",
        "cetriolo",
        "chiave",
        "chiedere",
        "chilo",
        "chimera",
        "chiodo",
        "chirurgo",
        "chitarra",
        "chiudere",
        "ciabatta",
        "ciao",
        "cibo",
        "ciccia",
        "cicerone",
        "ciclone",
        "cicogna",
        "cielo",
        "cifra",
        "cigno",
        "ciliegia",
        "cimitero",
        "cinema",
        "cinque",
        "cintura",
        "ciondolo",
        "ciotola",
        "cipolla",
        "cippato",
        "circuito",
        "cisterna",
        "citofono",
        "ciuccio",
        "civetta",
        "civico",
        "clausola",
        "cliente",
        "clima",
        "clinica",
        "cobra",
        "coccole",
        "cocktail",
        "cocomero",
        "codice",
        "coesione",
        "cogliere",
        "cognome",
        "colla",
        "colomba",
        "colpire",
        "coltello",
        "comando",
        "comitato",
        "commedia",
        "comodino",
        "compagna",
        "comune",
        "concerto",
        "condotto",
        "conforto",
        "congiura",
        "coniglio",
        "consegna",
        "conto",
        "convegno",
        "coperta",
        "copia",
        "coprire",
        "corazza",
        "corda",
        "corleone",
        "cornice",
        "corona",
        "corpo",
        "corrente",
        "corsa",
        "cortesia",
        "corvo",
        "coso",
        "costume",
        "cotone",
        "cottura",
        "cozza",
        "crampo",
        "cratere",
        "cravatta",
        "creare",
        "credere",
        "crema",
        "crescere",
        "crimine",
        "criterio",
        "croce",
        "crollare",
        "cronaca",
        "crostata",
        "croupier",
        "cubetto",
        "cucciolo",
        "cucina",
        "cultura",
        "cuoco",
        "cuore",
        "cupido",
        "cupola",
        "cura",
        "curva",
        "cuscino",
        "custode",
        "danzare",
        "data",
        "decennio",
        "decidere",
        "decollo",
        "dedicare",
        "dedurre",
        "definire",
        "delegare",
        "delfino",
        "delitto",
        "demone",
        "dentista",
        "denuncia",
        "deposito",
        "derivare",
        "deserto",
        "designer",
        "destino",
        "detonare",
        "dettagli",
        "diagnosi",
        "dialogo",
        "diamante",
        "diario",
        "diavolo",
        "dicembre",
        "difesa",
        "digerire",
        "digitare",
        "diluvio",
        "dinamica",
        "dipinto",
        "diploma",
        "diramare",
        "dire",
        "dirigere",
        "dirupo",
        "discesa",
        "disdetta",
        "disegno",
        "disporre",
        "dissenso",
        "distacco",
        "dito",
        "ditta",
        "diva",
        "divenire",
        "dividere",
        "divorare",
        "docente",
        "dolcetto",
        "dolore",
        "domatore",
        "domenica",
        "dominare",
        "donatore",
        "donna",
        "dorato",
        "dormire",
        "dorso",
        "dosaggio",
        "dottore",
        "dovere",
        "download",
        "dragone",
        "dramma",
        "dubbio",
        "dubitare",
        "duetto",
        "durata",
        "ebbrezza",
        "eccesso",
        "eccitare",
        "eclissi",
        "economia",
        "edera",
        "edificio",
        "editore",
        "edizione",
        "educare",
        "effetto",
        "egitto",
        "egiziano",
        "elastico",
        "elefante",
        "eleggere",
        "elemento",
        "elenco",
        "elezione",
        "elmetto",
        "elogio",
        "embrione",
        "emergere",
        "emettere",
        "eminenza",
        "emisfero",
        "emozione",
        "empatia",
        "energia",
        "enfasi",
        "enigma",
        "entrare",
        "enzima",
        "epidemia",
        "epilogo",
        "episodio",
        "epoca",
        "equivoco",
        "erba",
        "erede",
        "eroe",
        "erotico",
        "errore",
        "eruzione",
        "esaltare",
        "esame",
        "esaudire",
        "eseguire",
        "esempio",
        "esigere",
        "esistere",
        "esito",
        "esperto",
        "espresso",
        "essere",
        "estasi",
        "esterno",
        "estrarre",
        "eterno",
        "etica",
        "euforico",
        "europa",
        "evacuare",
        "evasione",
        "evento",
        "evidenza",
        "evitare",
        "evolvere",
        "fabbrica",
        "facciata",
        "fagiano",
        "fagotto",
        "falco",
        "fame",
        "famiglia",
        "fanale",
        "fango",
        "fantasia",
        "farfalla",
        "farmacia",
        "faro",
        "fase",
        "fastidio",
        "faticare",
        "fatto",
        "favola",
        "febbre",
        "femmina",
        "femore",
        "fenomeno",
        "fermata",
        "feromoni",
        "ferrari",
        "fessura",
        "festa",
        "fiaba",
        "fiamma",
        "fianco",
        "fiat",
        "fibbia",
        "fidare",
        "fieno",
        "figa",
        "figlio",
        "figura",
        "filetto",
        "filmato",
        "filosofo",
        "filtrare",
        "finanza",
        "finestra",
        "fingere",
        "finire",
        "finta",
        "finzione",
        "fiocco",
        "fioraio",
        "firewall",
        "firmare",
        "fisico",
        "fissare",
        "fittizio",
        "fiume",
        "flacone",
        "flagello",
        "flirtare",
        "flusso",
        "focaccia",
        "foglio",
        "fognario",
        "follia",
        "fonderia",
        "fontana",
        "forbici",
        "forcella",
        "foresta",
        "forgiare",
        "formare",
        "fornace",
        "foro",
        "fortuna",
        "forzare",
        "fosforo",
        "fotoni",
        "fracasso",
        "fragola",
        "frantumi",
        "fratello",
        "frazione",
        "freccia",
        "freddo",
        "frenare",
        "fresco",
        "friggere",
        "frittata",
        "frivolo",
        "frizione",
        "fronte",
        "frullato",
        "frumento",
        "frusta",
        "frutto",
        "fucile",
        "fuggire",
        "fulmine",
        "fumare",
        "funzione",
        "fuoco",
        "furbizia",
        "furgone",
        "furia",
        "furore",
        "fusibile",
        "fuso",
        "futuro",
        "gabbiano",
        "galassia",
        "gallina",
        "gamba",
        "gancio",
        "garanzia",
        "garofano",
        "gasolio",
        "gatto",
        "gazebo",
        "gazzetta",
        "gelato",
        "gemelli",
        "generare",
        "genitori",
        "gennaio",
        "geologia",
        "germania",
        "gestire",
        "gettare",
        "ghepardo",
        "ghiaccio",
        "giaccone",
        "giaguaro",
        "giallo",
        "giappone",
        "giardino",
        "gigante",
        "gioco",
        "gioiello",
        "giorno",
        "giovane",
        "giraffa",
        "giudizio",
        "giurare",
        "giusto",
        "globo",
        "gloria",
        "glucosio",
        "gnocca",
        "gocciola",
        "godere",
        "gomito",
        "gomma",
        "gonfiare",
        "gorilla",
        "governo",
        "gradire",
        "graffiti",
        "granchio",
        "grappolo",
        "grasso",
        "grattare",
        "gridare",
        "grissino",
        "grondaia",
        "grugnito",
        "gruppo",
        "guadagno",
        "guaio",
        "guancia",
        "guardare",
        "gufo",
        "guidare",
        "guscio",
        "gusto",
        "icona",
        "idea",
        "identico",
        "idolo",
        "idoneo",
        "idrante",
        "idrogeno",
        "igiene",
        "ignoto",
        "imbarco",
        "immagine",
        "immobile",
        "imparare",
        "impedire",
        "impianto",
        "importo",
        "impresa",
        "impulso",
        "incanto",
        "incendio",
        "incidere",
        "incontro",
        "incrocia",
        "incubo",
        "indagare",
        "indice",
        "indotto",
        "infanzia",
        "inferno",
        "infinito",
        "infranto",
        "ingerire",
        "inglese",
        "ingoiare",
        "ingresso",
        "iniziare",
        "innesco",
        "insalata",
        "inserire",
        "insicuro",
        "insonnia",
        "insulto",
        "interno",
        "introiti",
        "invasori",
        "inverno",
        "invito",
        "invocare",
        "ipnosi",
        "ipocrita",
        "ipotesi",
        "ironia",
        "irrigare",
        "iscritto",
        "isola",
        "ispirare",
        "isterico",
        "istinto",
        "istruire",
        "italiano",
        "jazz",
        "labbra",
        "labrador",
        "ladro",
        "lago",
        "lamento",
        "lampone",
        "lancetta",
        "lanterna",
        "lapide",
        "larva",
        "lasagne",
        "lasciare",
        "lastra",
        "latte",
        "laurea",
        "lavagna",
        "lavorare",
        "leccare",
        "legare",
        "leggere",
        "lenzuolo",
        "leone",
        "lepre",
        "letargo",
        "lettera",
        "levare",
        "levitare",
        "lezione",
        "liberare",
        "libidine",
        "libro",
        "licenza",
        "lievito",
        "limite",
        "lince",
        "lingua",
        "liquore",
        "lire",
        "listino",
        "litigare",
        "litro",
        "locale",
        "lottare",
        "lucciola",
        "lucidare",
        "luglio",
        "luna",
        "macchina",
        "madama",
        "madre",
        "maestro",
        "maggio",
        "magico",
        "maglione",
        "magnolia",
        "mago",
        "maialino",
        "maionese",
        "malattia",
        "male",
        "malloppo",
        "mancare",
        "mandorla",
        "mangiare",
        "manico",
        "manopola",
        "mansarda",
        "mantello",
        "manubrio",
        "manzo",
        "mappa",
        "mare",
        "margine",
        "marinaio",
        "marmotta",
        "marocco",
        "martello",
        "marzo",
        "maschera",
        "matrice",
        "maturare",
        "mazzetta",
        "meandri",
        "medaglia",
        "medico",
        "medusa",
        "megafono",
        "melone",
        "membrana",
        "menta",
        "mercato",
        "meritare",
        "merluzzo",
        "mese",
        "mestiere",
        "metafora",
        "meteo",
        "metodo",
        "mettere",
        "miele",
        "miglio",
        "miliardo",
        "mimetica",
        "minatore",
        "minuto",
        "miracolo",
        "mirtillo",
        "missile",
        "mistero",
        "misura",
        "mito",
        "mobile",
        "moda",
        "moderare",
        "moglie",
        "molecola",
        "molle",
        "momento",
        "moneta",
        "mongolia",
        "monologo",
        "montagna",
        "morale",
        "morbillo",
        "mordere",
        "mosaico",
        "mosca",
        "mostro",
        "motivare",
        "moto",
        "mulino",
        "mulo",
        "muovere",
        "muraglia",
        "muscolo",
        "museo",
        "musica",
        "mutande",
        "nascere",
        "nastro",
        "natale",
        "natura",
        "nave",
        "navigare",
        "negare",
        "negozio",
        "nemico",
        "nero",
        "nervo",
        "nessuno",
        "nettare",
        "neutroni",
        "neve",
        "nevicare",
        "nicotina",
        "nido",
        "nipote",
        "nocciola",
        "noleggio",
        "nome",
        "nonno",
        "norvegia",
        "notare",
        "notizia",
        "nove",
        "nucleo",
        "nuda",
        "nuotare",
        "nutrire",
        "obbligo",
        "occhio",
        "occupare",
        "oceano",
        "odissea",
        "odore",
        "offerta",
        "officina",
        "offrire",
        "oggetto",
        "oggi",
        "olfatto",
        "olio",
        "oliva",
        "ombelico",
        "ombrello",
        "omuncolo",
        "ondata",
        "onore",
        "opera",
        "opinione",
        "opuscolo",
        "opzione",
        "orario",
        "orbita",
        "orchidea",
        "ordine",
        "orecchio",
        "orgasmo",
        "orgoglio",
        "origine",
        "orologio",
        "oroscopo",
        "orso",
        "oscurare",
        "ospedale",
        "ospite",
        "ossigeno",
        "ostacolo",
        "ostriche",
        "ottenere",
        "ottimo",
        "ottobre",
        "ovest",
        "pacco",
        "pace",
        "pacifico",
        "padella",
        "pagare",
        "pagina",
        "pagnotta",
        "palazzo",
        "palestra",
        "palpebre",
        "pancetta",
        "panfilo",
        "panino",
        "pannello",
        "panorama",
        "papa",
        "paperino",
        "paradiso",
        "parcella",
        "parente",
        "parlare",
        "parodia",
        "parrucca",
        "partire",
        "passare",
        "pasta",
        "patata",
        "patente",
        "patogeno",
        "patriota",
        "pausa",
        "pazienza",
        "peccare",
        "pecora",
        "pedalare",
        "pelare",
        "pena",
        "pendenza",
        "penisola",
        "pennello",
        "pensare",
        "pentirsi",
        "percorso",
        "perdono",
        "perfetto",
        "perizoma",
        "perla",
        "permesso",
        "persona",
        "pesare",
        "pesce",
        "peso",
        "petardo",
        "petrolio",
        "pezzo",
        "piacere",
        "pianeta",
        "piastra",
        "piatto",
        "piazza",
        "piccolo",
        "piede",
        "piegare",
        "pietra",
        "pigiama",
        "pigliare",
        "pigrizia",
        "pilastro",
        "pilota",
        "pinguino",
        "pioggia",
        "piombo",
        "pionieri",
        "piovra",
        "pipa",
        "pirata",
        "pirolisi",
        "piscina",
        "pisolino",
        "pista",
        "pitone",
        "piumino",
        "pizza",
        "plastica",
        "platino",
        "poesia",
        "poiana",
        "polaroid",
        "polenta",
        "polimero",
        "pollo",
        "polmone",
        "polpetta",
        "poltrona",
        "pomodoro",
        "pompa",
        "popolo",
        "porco",
        "porta",
        "porzione",
        "possesso",
        "postino",
        "potassio",
        "potere",
        "poverino",
        "pranzo",
        "prato",
        "prefisso",
        "prelievo",
        "premio",
        "prendere",
        "prestare",
        "pretesa",
        "prezzo",
        "primario",
        "privacy",
        "problema",
        "processo",
        "prodotto",
        "profeta",
        "progetto",
        "promessa",
        "pronto",
        "proposta",
        "proroga",
        "prossimo",
        "proteina",
        "prova",
        "prudenza",
        "pubblico",
        "pudore",
        "pugilato",
        "pulire",
        "pulsante",
        "puntare",
        "pupazzo",
        "puzzle",
        "quaderno",
        "qualcuno",
        "quarzo",
        "quercia",
        "quintale",
        "rabbia",
        "racconto",
        "radice",
        "raffica",
        "ragazza",
        "ragione",
        "rammento",
        "ramo",
        "rana",
        "randagio",
        "rapace",
        "rapinare",
        "rapporto",
        "rasatura",
        "ravioli",
        "reagire",
        "realista",
        "reattore",
        "reazione",
        "recitare",
        "recluso",
        "record",
        "recupero",
        "redigere",
        "regalare",
        "regina",
        "regola",
        "relatore",
        "reliquia",
        "remare",
        "rendere",
        "reparto",
        "resina",
        "resto",
        "rete",
        "retorica",
        "rettile",
        "revocare",
        "riaprire",
        "ribadire",
        "ribelle",
        "ricambio",
        "ricetta",
        "richiamo",
        "ricordo",
        "ridurre",
        "riempire",
        "riferire",
        "riflesso",
        "righello",
        "rilancio",
        "rilevare",
        "rilievo",
        "rimanere",
        "rimborso",
        "rinforzo",
        "rinuncia",
        "riparo",
        "ripetere",
        "riposare",
        "ripulire",
        "risalita",
        "riscatto",
        "riserva",
        "riso",
        "rispetto",
        "ritaglio",
        "ritmo",
        "ritorno",
        "ritratto",
        "rituale",
        "riunione",
        "riuscire",
        "riva",
        "robotica",
        "rondine",
        "rosa",
        "rospo",
        "rosso",
        "rotonda",
        "rotta",
        "roulotte",
        "rubare",
        "rubrica",
        "ruffiano",
        "rumore",
        "ruota",
        "ruscello",
        "sabbia",
        "sacco",
        "saggio",
        "sale",
        "salire",
        "salmone",
        "salto",
        "salutare",
        "salvia",
        "sangue",
        "sanzioni",
        "sapere",
        "sapienza",
        "sarcasmo",
        "sardine",
        "sartoria",
        "sbalzo",
        "sbarcare",
        "sberla",
        "sborsare",
        "scadenza",
        "scafo",
        "scala",
        "scambio",
        "scappare",
        "scarpa",
        "scatola",
        "scelta",
        "scena",
        "sceriffo",
        "scheggia",
        "schiuma",
        "sciarpa",
        "scienza",
        "scimmia",
        "sciopero",
        "scivolo",
        "sclerare",
        "scolpire",
        "sconto",
        "scopa",
        "scordare",
        "scossa",
        "scrivere",
        "scrupolo",
        "scuderia",
        "scultore",
        "scuola",
        "scusare",
        "sdraiare",
        "secolo",
        "sedativo",
        "sedere",
        "sedia",
        "segare",
        "segreto",
        "seguire",
        "semaforo",
        "seme",
        "senape",
        "seno",
        "sentiero",
        "separare",
        "sepolcro",
        "sequenza",
        "serata",
        "serpente",
        "servizio",
        "sesso",
        "seta",
        "settore",
        "sfamare",
        "sfera",
        "sfidare",
        "sfiorare",
        "sfogare",
        "sgabello",
        "sicuro",
        "siepe",
        "sigaro",
        "silenzio",
        "silicone",
        "simbiosi",
        "simpatia",
        "simulare",
        "sinapsi",
        "sindrome",
        "sinergia",
        "sinonimo",
        "sintonia",
        "sirena",
        "siringa",
        "sistema",
        "sito",
        "smalto",
        "smentire",
        "smontare",
        "soccorso",
        "socio",
        "soffitto",
        "software",
        "soggetto",
        "sogliola",
        "sognare",
        "soldi",
        "sole",
        "sollievo",
        "solo",
        "sommario",
        "sondare",
        "sonno",
        "sorpresa",
        "sorriso",
        "sospiro",
        "sostegno",
        "sovrano",
        "spaccare",
        "spada",
        "spagnolo",
        "spalla",
        "sparire",
        "spavento",
        "spazio",
        "specchio",
        "spedire",
        "spegnere",
        "spendere",
        "speranza",
        "spessore",
        "spezzare",
        "spiaggia",
        "spiccare",
        "spiegare",
        "spiffero",
        "spingere",
        "sponda",
        "sporcare",
        "spostare",
        "spremuta",
        "spugna",
        "spumante",
        "spuntare",
        "squadra",
        "squillo",
        "staccare",
        "stadio",
        "stagione",
        "stallone",
        "stampa",
        "stancare",
        "starnuto",
        "statura",
        "stella",
        "stendere",
        "sterzo",
        "stilista",
        "stimolo",
        "stinco",
        "stiva",
        "stoffa",
        "storia",
        "strada",
        "stregone",
        "striscia",
        "studiare",
        "stufa",
        "stupendo",
        "subire",
        "successo",
        "sudare",
        "suono",
        "superare",
        "supporto",
        "surfista",
        "sussurro",
        "svelto",
        "svenire",
        "sviluppo",
        "svolta",
        "svuotare",
        "tabacco",
        "tabella",
        "tabu",
        "tacchino",
        "tacere",
        "taglio",
        "talento",
        "tangente",
        "tappeto",
        "tartufo",
        "tassello",
        "tastiera",
        "tavolo",
        "tazza",
        "teatro",
        "tedesco",
        "telaio",
        "telefono",
        "tema",
        "temere",
        "tempo",
        "tendenza",
        "tenebre",
        "tensione",
        "tentare",
        "teologia",
        "teorema",
        "termica",
        "terrazzo",
        "teschio",
        "tesi",
        "tesoro",
        "tessera",
        "testa",
        "thriller",
        "tifoso",
        "tigre",
        "timbrare",
        "timido",
        "tinta",
        "tirare",
        "tisana",
        "titano",
        "titolo",
        "toccare",
        "togliere",
        "topolino",
        "torcia",
        "torrente",
        "tovaglia",
        "traffico",
        "tragitto",
        "training",
        "tramonto",
        "transito",
        "trapezio",
        "trasloco",
        "trattore",
        "trazione",
        "treccia",
        "tregua",
        "treno",
        "triciclo",
        "tridente",
        "trilogia",
        "tromba",
        "troncare",
        "trota",
        "trovare",
        "trucco",
        "tubo",
        "tulipano",
        "tumulto",
        "tunisia",
        "tuono",
        "turista",
        "tuta",
        "tutelare",
        "tutore",
        "ubriaco",
        "uccello",
        "udienza",
        "udito",
        "uffa",
        "umanoide",
        "umore",
        "unghia",
        "unguento",
        "unicorno",
        "unione",
        "universo",
        "uomo",
        "uragano",
        "uranio",
        "urlare",
        "uscire",
        "utente",
        "utilizzo",
        "vacanza",
        "vacca",
        "vaglio",
        "vagonata",
        "valle",
        "valore",
        "valutare",
        "valvola",
        "vampiro",
        "vaniglia",
        "vanto",
        "vapore",
        "variante",
        "vasca",
        "vaselina",
        "vassoio",
        "vedere",
        "vegetale",
        "veglia",
        "veicolo",
        "vela",
        "veleno",
        "velivolo",
        "velluto",
        "vendere",
        "venerare",
        "venire",
        "vento",
        "veranda",
        "verbo",
        "verdura",
        "vergine",
        "verifica",
        "vernice",
        "vero",
        "verruca",
        "versare",
        "vertebra",
        "vescica",
        "vespaio",
        "vestito",
        "vesuvio",
        "veterano",
        "vetro",
        "vetta",
        "viadotto",
        "viaggio",
        "vibrare",
        "vicenda",
        "vichingo",
        "vietare",
        "vigilare",
        "vigneto",
        "villa",
        "vincere",
        "violino",
        "vipera",
        "virgola",
        "virtuoso",
        "visita",
        "vita",
        "vitello",
        "vittima",
        "vivavoce",
        "vivere",
        "viziato",
        "voglia",
        "volare",
        "volpe",
        "volto",
        "volume",
        "vongole",
        "voragine",
        "vortice",
        "votare",
        "vulcano",
        "vuotare",
        "zabaione",
        "zaffiro",
        "zainetto",
        "zampa",
        "zanzara",
        "zattera",
        "zavorra",
        "zenzero",
        "zero",
        "zingaro",
        "zittire",
        "zoccolo",
        "zolfo",
        "zombie",
        "zucchero"
    ]



# -*- coding: utf-8 -*-
from __future__ import unicode_literals
import codecs
import os
import re
from distutils.core import setup

from setuptools import find_packages

here = os.path.abspath(os.path.dirname(__file__))


def find_version(*parts):
    """
    Figure out version number without importing the package.
    https://packaging.python.org/guides/single-sourcing-package-version/
    """
    with codecs.open(os.path.join(here, *parts), 'r', errors='ignore') as fp:
        version_file = fp.read()
    version_match = re.search(r"^__version__ = ['\"](.*)['\"]",
                              version_file, re.M)
    if version_match:
        return version_match.group(1)
    raise RuntimeError("Unable to find version string.")


version = find_version('monero', '__init__.py')

setup(
    name = 'monero',
    version = version,
    description = 'A comprehensive Python module for handling Monero cryptocurrency',
    url = 'https://github.com/monero-ecosystem/monero-python/',
    long_description = open('README.rst', 'rb').read().decode('utf-8'),
    install_requires = open('requirements.txt', 'r').read().splitlines(),
    tests_require=open('test_requirements.txt', 'r').read().splitlines(),
    setup_requires=[
        'pytest-runner',
    ],
    packages = find_packages('.', exclude=['tests']),
    include_package_data = True,
    author = 'Michał Sałaban',
    author_email = 'michal@salaban.info',
    license = 'BSD-3-Clause',
    classifiers = [
        'Development Status :: 4 - Beta',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: BSD License',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Topic :: Software Development :: Libraries :: Python Modules',
    ],
    keywords = 'monero cryptocurrency',
    test_suite='tests',
)
